from machine import Pin
import time

# Define segment GPIOs for a to g
segments = [
    Pin(0, Pin.OUT),  # a
    Pin(1, Pin.OUT),  # b
    Pin(2, Pin.OUT),  # c
    Pin(3, Pin.OUT),  # d
    Pin(4, Pin.OUT),  # e
    Pin(6, Pin.OUT),  # f
    Pin(7, Pin.OUT)   # g
]

# Define digit to segment mapping for common cathode
digit_segments = [
    # a b c d e f g
    [0,1,1,0,0,0,0],  # 1
    [1,1,0,1,1,0,1],  # 2
    [1,1,1,1,0,0,1],  # 3
    [0,1,1,0,0,1,1],  # 4
    [1,0,1,1,0,1,1],  # 5
    [1,0,1,1,1,1,1],  # 6
    [1,1,1,0,0,0,0],  # 7
    [1,1,1,1,1,1,1],  # 8
    [1,1,1,1,0,1,1]   # 9
]

# Push button pin
button = Pin(5, Pin.IN, Pin.PULL_UP)

count = 0

def display_digit(n):
    if 1 <= n <= 9:
        pattern = digit_segments[n - 1]
        for i in range(7):
            segments[i].value(pattern[i])
    else:
        # Turn off all segments
        for seg in segments:
            seg.value(0)

# Start with display off
display_digit(0)

# Main loop
while True:
    if button.value() == 0:  # Button pressed (active low)
        count += 1
        if count > 9:
            count = 1
        display_digit(count)
        time.sleep(0.3)  # Debounce and prevent multiple counts
        # Wait for release
        while button.value() == 0:
            time.sleep(0.01)
    time.sleep(0.01)
